#https://github.com/candlepin/subscription-manager/blob/master/LICENSE
#
# openEuler got this spec file from Candlepin community.
# openEuler rewrote several sentences.
#

%global fedora 0
%global rhel 8

# Prefer systemd over sysv on Fedora and RHEL 7+
%global use_systemd 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7) || (0%{?suse_version} && 0%{?suse_version} >= 1315)
# For optional building of ostree-plugin sub package. Unrelated to systemd
# but the same versions apply at the moment.
%global has_ostree %use_systemd && 0%{?suse_version} == 0
%global use_initial_setup 1
%global use_firstboot 0
%global use_inotify 1
%global py2_package_prefix python2

%bcond_with initial-setup-addon

%if (0%{?rhel} >= 7 || 0%{?fedora})
%global dmidecode_version >= 3.12.2-2
%endif

# borrowed from dnf spec file & tweaked
%if (0%{?rhel} && 0%{?rhel} <= 7) || 0%{?suse_version}
%bcond_with python3
%else
%bcond_without python3
%endif

%bcond_without python2_rhsm

%if %{with python3}
%global use_subman_gui 0
%else
%global use_subman_gui 1
%endif

%global rhsm_plugins_dir  /usr/share/rhsm-plugins
# on recent Fedora and RHEL 7, let's not use m2crypto
%global use_m2crypto (0%{?fedora} < 23 && 0%{?rhel} < 7)

%if %{use_systemd}
# Note that the global gtk3 will be undefined if it's not used
%global gtk3 1
%endif

%if 0%{?rhel} == 6 || 0%{?suse_version}
%global use_initial_setup 0
%global use_firstboot 1
%global use_inotify 0
%endif

%if %{use_subman_gui} || %{use_initial_setup} || %{use_firstboot}
%global use_rhsm_gtk 1
%else
%global use_rhsm_gtk 0
%endif

%global use_dnf (%{with python3} && (0%{?fedora} || (0%{?rhel}))) || (0%{?rhel} >= 7)
%global use_yum (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?suse_version})
%global use_cockpit 0%{?fedora} || 0%{?rhel} >= 7

%if %{with python3}
%global python_sitearch %python3_sitearch
%global __python %__python3
%global py_package_prefix python%{python3_pkgversion}
%global rhsm_package_name %{py_package_prefix}-subscription-manager-rhsm
%define include_syspurpose 1
%else
%global py_package_prefix python
%global rhsm_package_name subscription-manager-rhsm
%endif

%global _hardened_build 1
%{!?__global_ldflags: %global __global_ldflags -Wl,-z,relro -Wl,-z,now}

%if %{has_ostree}
%define install_ostree INSTALL_OSTREE_PLUGIN=true
%else
%define install_ostree INSTALL_OSTREE_PLUGIN=false
%endif

# makefile will guess, but be specific.
%if 0%{?gtk3}
%define gtk_version GTK_VERSION=3
%else
%define gtk_version GTK_VERSION=2
%endif

%if %{use_initial_setup}
%define post_boot_tool INSTALL_INITIAL_SETUP=true INSTALL_FIRSTBOOT=false
%else
%define post_boot_tool INSTALL_INITIAL_SETUP=false INSTALL_FIRSTBOOT=true
%endif

%if 0%{?suse_version}
%define install_zypper_plugins INSTALL_ZYPPER_PLUGINS=true
%else
%define install_zypper_plugins INSTALL_ZYPPER_PLUGINS=false
%endif

# makefile defaults to INSTALL_DNF_PLUGIN=false
%if %{use_dnf}
%define install_dnf_plugins INSTALL_DNF_PLUGINS=true
%else
%define install_dnf_plugins INSTALL_DNF_PLUGINS=false
%endif

# makefile defaults to INSTALL_DNF_PLUGIN=true
%if %{use_yum}
%define install_yum_plugins INSTALL_YUM_PLUGINS=true
%else
%define install_yum_plugins INSTALL_YUM_PLUGINS=false
%endif

%if %{use_systemd}
%define with_systemd WITH_SYSTEMD=true
%else
%define with_systemd WITH_SYSTEMD=false
%endif

%if %{use_subman_gui}
%define with_subman_gui WITH_SUBMAN_GUI=true
%else
%define with_subman_gui WITH_SUBMAN_GUI=false
%endif

%if %{use_cockpit} && !0%{use_subman_gui}
%define with_cockpit WITH_COCKPIT=true
%else
%define with_cockpit WITH_COCKPIT=false
%endif

%define subpackages SUBPACKAGES="%{?include_syspurpose:syspurpose}"

Name: subscription-manager
Version: 1.23.3
Release: 5
Summary: Tools and libraries for subscription and repository management
Group:   System Environment/Base
License: GPLv2
URL:     http://www.candlepinproject.org/

# How to create the source tarball:
#
# git clone https://github.com/candlepin/subscription-manager.git
# yum install tito
# tito build --tag subscription-manager-$VERSION-$RELEASE --tgz
Source0: %{name}-%{version}.tar.gz
# this is a little different from the Source0, because of limitations in tito,
# namely that tito expects only one source tarball
Source1: %{name}-cockpit-%{version}.tar.gz
%if 0%{?suse_version}
Source2: subscription-manager-rpmlintrc
%endif
Patch9000:	subscription-manager-fix-module-os-has-no-attribute-.patch

#%if 0%{?suse_version} < 1200
#BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
#%endif

# The following macro examples are preceeded by '%' to stop macro expansion
# in the comments. (See https://bugzilla.redhat.com/show_bug.cgi?id=1224660 for
# why this is necessary)
# A note about the %%{?foo:bar} %%{!?foo:quux} convention.  The %%{?foo:bar}
# syntax evaluates foo and if it is **defined**, it expands to "bar" otherwise it
# expands to nothing.  The %%{!?foo:quux} syntax similarily only the expansion
# occurs when foo is **undefined**.  Since one and only one of the expressions will
# expand we can more concisely handle when a dependency has different names in
# SUSE versus RHEL.  The traditional if syntax gets extremely confusing when
# nesting is required since RPM requires the various preamble directives to be
# at the start of a line making meaningful indentation impossible.

BuildRequires:	git
Requires:  %{py_package_prefix}-ethtool
Requires:  %{py_package_prefix}-iniparse
Requires:  %{py_package_prefix}-decorator
Requires:  virt-what
Requires:  %{rhsm_package_name} = %{version}
Requires:  %{py_package_prefix}-six
Requires:  %{py_package_prefix}-dateutil
Requires:  %{py_package_prefix}-setuptools

%if %{with python3}
Requires: python3-dbus
%else
Requires: %{?suse_version:dbus-1-python} %{!?suse_version:dbus-python}
%endif

%if %{use_yum}
Requires: %{?suse_version:yum} %{!?suse_version:yum >= 3.2.29-73}
%endif

%if (%{use_dnf} && (0%{?fedora} || 0%{?rhel} >= 8))
Requires: dnf-plugin-subscription-manager = %{version}
%endif

# Support GTK2 and GTK3 on both SUSE and RHEL...
%if 0%{?suse_version}
Requires: %{?gtk3:python-gobject} %{!?gtk3:python-gobject2, libzypp, zypp-plugin-python, python-zypp}
%else
Requires:  usermode
%if %{with python3}
Requires: python3-gobject-base
%else
Requires:  %{?gtk3:gobject-introspection, pygobject3-base} %{!?gtk3:pygobject2}
%endif
# There's no dmi to read on these arches, so don't pull in this dep.
# Additionally, dmidecode isn't packaged at all on SUSE
%ifnarch ppc ppc64 s390 s390x
Requires:  %{py_package_prefix}-dmidecode %{?dmidecode_version}
%endif
%endif

%if %use_inotify
Requires:  %{py_package_prefix}-inotify
%endif

%if %use_systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%else
Requires: %{?suse_version:aaa_base} %{!?suse_version:chkconfig}
Requires(post): %{?suse_version:aaa_base} %{!?suse_version:chkconfig}
Requires(preun): %{?suse_version:aaa_base} %{!?suse_version:chkconfig, initscripts}
%endif

BuildRequires: %{?suse_version:python-devel >= 2.6} %{!?suse_version:%{py_package_prefix}-devel}
BuildRequires: openssl-devel
BuildRequires: gcc %{_vendor}-release
BuildRequires: %{py_package_prefix}-setuptools
BuildRequires: gettext
BuildRequires: intltool
BuildRequires: libnotify-devel
BuildRequires: %{py_package_prefix}-six

%if %{use_subman_gui} || %{use_cockpit}
BuildRequires: desktop-file-utils
%endif

BuildRequires: %{?suse_version:dbus-1-glib-devel} %{!?suse_version:dbus-glib-devel}
BuildRequires: %{?suse_version:distribution-release} %{!?suse_version:system-release}
BuildRequires: %{?suse_version:gconf2-devel} %{!?suse_version:GConf2-devel}
BuildRequires: %{?suse_version:update-desktop-files} %{!?suse_version:scrollkeeper}

BuildRequires: %{?gtk3:gtk3-devel} %{!?gtk3:gtk2-devel}

%if 0%{?suse_version}
BuildRequires: libzypp
%endif

%if 0%{?suse_version} >= 1210
BuildRequires: systemd-rpm-macros
%endif

%if %use_systemd
# We need the systemd RPM macros
BuildRequires: systemd
%endif

%description
The Subscription Manager package provides programs and libraries to allow users
to manage subscriptions and yum repositories from the Red Hat entitlement
platform.

%if %{with python3}
%package -n %{py_package_prefix}-syspurpose
Summary: A commandline utility for declaring system syspurpose
Group: System Environment/Base

%description -n %{py_package_prefix}-syspurpose
Provides the syspurpose commandline utility. This utility manages the
system syspurpose.
%endif


%package -n subscription-manager-plugin-container
Summary: A plugin for handling container content
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}

%description -n subscription-manager-plugin-container
Enables handling of content of type 'containerImage' in any certificates
from the server. Populates /etc/docker/certs.d appropriately.


%if %{use_rhsm_gtk}
%package -n rhsm-gtk
Summary: GTK+ widgets used by subscription-manager-gui and initial_setup
Group: System Environment/Base
Requires: %{?gtk3:%{py_package_prefix}-gobject, gtk3} %{!?gtk3:pygtk2, pygtk2-libglade}
Requires: usermode-gtk
# Fedora can figure this out automatically, but RHEL cannot:
# See #987071
Requires: librsvg2%{?_isa}

%if 0%{?gtk3}
Requires: font(cantarell)
%else
Requires: %{?suse_version:dejavu} %{!?suse_version:dejavu-sans-fonts}
%endif

%if !0%{?suse_version}
Requires(post): scrollkeeper
Requires(postun): scrollkeeper
%endif

%description -n rhsm-gtk
This package contains GUI and widgets used by subscription-manager-gui
and RHSM initial_setup module for Anaconda.
%endif


%if %{use_subman_gui}
%package -n subscription-manager-gui
Summary: A GUI interface to manage Red Hat product subscriptions
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: gnome-icon-theme

# We need pygtk3 and gtk2 until rhsm-icon is ported to gtk3
Requires: rhsm-gtk = %{version}-%{release}

# Renamed from -gnome, so obsolete it properly
Obsoletes: %{name}-gnome < 1.0.3-1
Provides: %{name}-gnome = %{version}-%{release}

%description -n subscription-manager-gui
This package contains a GTK+ graphical interface for configuring and
registering a system with a Red Hat Entitlement platform and manage
subscriptions.
%endif


%package -n subscription-manager-migration
Summary: Migration scripts for moving to certificate based subscriptions
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: rhnlib

# Since the migration data package is not in Fedora, we can only require it
# on RHEL.
#%if 0%{?rhel}
#Requires: subscription-manager-migration-data
#%endif

%description -n subscription-manager-migration
This package contains scripts that aid in moving to certificate based
subscriptions


%if %use_dnf
%package -n dnf-plugin-subscription-manager
Summary: Subscription Manager plugins for DNF
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: dnf >= 1.0.0
%if %{with python3}
Requires: python3-dnf-plugins-core
%else
Requires: python2-dnf-plugins-core
%endif

%description -n dnf-plugin-subscription-manager
This package provides plugins to interact with repositories and subscriptions
from the Red Hat entitlement platform; contains subscription-manager and
product-id plugins.
%endif


%if %use_firstboot
%package -n subscription-manager-firstboot
Summary: Firstboot screens for subscription manager
Group: System Environment/Base
Requires: rhsm-gtk = %{version}-%{release}
Requires: rhn-setup-gnome

# Fedora can figure this out automatically, but RHEL cannot:
Requires: librsvg2

%description -n subscription-manager-firstboot
This package contains the firstboot screens for subscription-manager.
%endif

%if %{with initial-setup-addon}
%if %use_initial_setup
%package -n subscription-manager-initial-setup-addon
Summary: initial-setup screens for subscription-manager
Group: System Environment/Base
Requires: rhsm-gtk = %{version}-%{release}
Requires: initial-setup-gui >= 0.3.9.24-1
Obsoletes: subscription-manager-firstboot < 1.15.3-1

%description -n subscription-manager-initial-setup-addon
This package contains the initial-setup screens for subscription-manager.
%endif
%endif

%if %has_ostree
%package -n subscription-manager-plugin-ostree
Summary: A plugin for handling OSTree content.
Group: System Environment/Base

Requires: %{py_package_prefix}-gobject-base
# plugin needs a slightly newer version of python-iniparse for 'tidy'
Requires:  %{py_package_prefix}-iniparse >= 0.4
Requires: %{name} = %{version}-%{release}

%description -n subscription-manager-plugin-ostree
Enables handling of content of type 'ostree' in any certificates
from the server. Populates /ostree/repo/config as well as updates
the remote in the currently deployed .origin file.
%endif


%package -n %{rhsm_package_name}
Summary: A Python library to communicate with a Red Hat Unified Entitlement Platform
Group: Development/Libraries

%if %use_m2crypto
Requires: %{?suse_version:python-m2crypto} %{!?suse_version:m2crypto}
%endif
Requires: %{py_package_prefix}-dateutil
Requires: %{py_package_prefix}-iniparse
# rpm-python is an old name for python2-rpm but RHEL6 uses the old name
Requires: %{py_package_prefix}-six
Requires: subscription-manager-rhsm-certificates = %{version}-%{release}
# Required by Fedora packaging guidelines
%{?python_provide:%python_provide %{py_package_prefix}-rhsm}
%if %{with python3}
Requires: python3-rpm
Provides: python3-rhsm = %{version}-%{release}
Obsoletes: python3-rhsm <= 1.20.3-1
Provides: python-rhsm = %{version}-%{release}
Obsoletes: python-rhsm <= 1.20.3-1
%else
Requires: rpm-python
Provides: python-rhsm = %{version}-%{release}
Obsoletes: python-rhsm <= 1.20.3-1
%endif

%description -n %{rhsm_package_name}
A small library for communicating with the REST interface of a Red Hat Unified
Entitlement Platform. This interface is used for the management of system
entitlements, certificates, and access to content.


%if %{with python2_rhsm}
%package -n python2-subscription-manager-rhsm
Summary: A Python library to communicate with a Red Hat Unified Entitlement Platform
Group: Development/Libraries

BuildRequires: python2-devel

%if %use_m2crypto
Requires: %{?suse_version:python-m2crypto} %{!?suse_version:m2crypto}
%endif
Requires: %{py2_package_prefix}-dateutil
Requires: %{py2_package_prefix}-iniparse
# rpm-python is an old name for python2-rpm but RHEL6 uses the old name
Requires: %{py2_package_prefix}-six
Requires: subscription-manager-rhsm-certificates = %{version}-%{release}
# Required by Fedora packaging guidelines
%{?python_provide:%python_provide %{py2_package_prefix}-rhsm}
Requires: rpm-python
Provides: python-rhsm = %{version}-%{release}
Obsoletes: python-rhsm <= 1.20.3-1

%description -n python2-subscription-manager-rhsm
A small library for communicating with the REST interface of a Red Hat Unified
Entitlement Platform. This interface is used for the management of system
entitlements, certificates, and access to content.
%endif

%package -n subscription-manager-rhsm-certificates
Summary: Certificates required to communicate with a Red Hat Unified Entitlement Platform
Group: Development/Libraries
Provides: python-rhsm-certificates = %{version}-%{release}
Obsoletes: python-rhsm-certificates <= 1.20.3-1

%description -n subscription-manager-rhsm-certificates
This package contains certificates required for communicating with the REST interface
of a Red Hat Unified Entitlement Platform, used for the management of system entitlements
and to receive access to content.

%if %use_cockpit
%package -n subscription-manager-cockpit
Summary: Subscription Manager Cockpit UI
License: GPLv2
BuildArch: noarch

Requires: subscription-manager
Requires: cockpit-bridge
Requires: cockpit-shell

%description -n subscription-manager-cockpit
Subscription Manager Cockpit UI
%endif

%prep
%autosetup -a 0 -a 1 -p1
sed -i  's/\/etc\/redhat-release/\/etc\/%{_vendor}-release/g' Makefile

%build
make -f Makefile VERSION=%{version}-%{release} CFLAGS="%{optflags}" \
    LDFLAGS="%{__global_ldflags}" OS_DIST="%{dist}" PYTHON="%{__python}" %{?gtk_version} %{?subpackages} %{?include_syspurpose:INCLUDE_SYSPURPOSE="1"}

%if %{with python2_rhsm}
python2 ./setup.py build --quiet --gtk-version=%{?gtk3:3}%{?!gtk3:2} --rpm-version=%{version}-%{release}
%endif

%install
rm -rf %{buildroot}
make -f Makefile install VERSION=%{version}-%{release} \
    PYTHON=%{__python} PREFIX=%{_prefix} \
    DESTDIR=%{buildroot} PYTHON_SITELIB=%{python_sitearch} \
    OS_VERSION=%{?fedora}%{?rhel}%{?suse_version} OS_DIST=%{dist} \
    %{?install_ostree} %{?post_boot_tool} %{?gtk_version} \
    %{?install_yum_plugins} %{?install_dnf_plugins} \
    %{?install_zypper_plugins} \
    %{?with_systemd} \
    %{?with_subman_gui} \
    %{?with_cockpit} \
    %{?subpackages} \
    %{?include_syspurpose:INCLUDE_SYSPURPOSE="1"}

%if %{with python2_rhsm}
mkdir -p %{buildroot}%{python2_sitearch}/rhsm
# Build binary extension in Python2 site-packages directory
python2 ./setup.py build_ext --build-lib %{buildroot}%{python2_sitearch} --quiet
# Copy all *.py file from Python3 to Python2 directory
cp %{buildroot}%{python_sitearch}/rhsm/*.py %{buildroot}%{python2_sitearch}/rhsm/
%endif

%if 0%{?suse_version}
%suse_update_desktop_file -n -r subscription-manager-gui Settings PackageManager
%endif

%if %use_subman_gui
desktop-file-validate %{buildroot}/etc/xdg/autostart/rhsm-icon.desktop
desktop-file-validate %{buildroot}/usr/share/applications/subscription-manager-gui.desktop
%else
%if %use_cockpit
desktop-file-validate %{buildroot}/usr/share/applications/subscription-manager-cockpit.desktop
%endif
%endif

%find_lang rhsm

#%if %{use_subman_gui}
#%find_lang %{name} --with-gnome
#%endif

# fix timestamps on our byte compiled files so they match across arches
find %{buildroot} -name \*.py -exec touch -r %{SOURCE0} '{}' \;

# fake out the redhat.repo file
%if %{use_yum} || %{use_dnf}
    %{__mkdir} %{buildroot}%{_sysconfdir}/yum.repos.d
    touch %{buildroot}%{_sysconfdir}/yum.repos.d/redhat.repo
%endif

# fake out the certificate directories
%{__mkdir_p} %{buildroot}%{_sysconfdir}/pki/consumer
%{__mkdir_p} %{buildroot}%{_sysconfdir}/pki/entitlement

# Setup cert directories for the container plugin:
%{__mkdir_p} %{buildroot}%{_sysconfdir}/docker/certs.d/
%{__mkdir} %{buildroot}%{_sysconfdir}/docker/certs.d/cdn.redhat.com
install -m 644 %{_builddir}/%{buildsubdir}/etc-conf/redhat-entitlement-authority.pem %{buildroot}%{_sysconfdir}/docker/certs.d/cdn.redhat.com/redhat-entitlement-authority.crt

%{__mkdir_p} %{buildroot}%{_sysconfdir}/etc/rhsm/ca
install -m 644 %{_builddir}/%{buildsubdir}/etc-conf/redhat-entitlement-authority.pem %{buildroot}/%{_sysconfdir}/rhsm/ca/redhat-entitlement-authority.pem
install -m 644 %{_builddir}/%{buildsubdir}/etc-conf/ca/redhat-uep.pem %{buildroot}/%{_sysconfdir}/rhsm/ca/redhat-uep.pem

%if %use_cockpit
    # install cockpit dist targz
    tar --strip-components=1 -xzf %{SOURCE1} -C %{buildroot}
%endif

%if %{with python3}
%py_byte_compile %{__python3} %{buildroot}%{rhsm_plugins_dir}/
%py_byte_compile %{__python3} %{buildroot}%{_datadir}/anaconda/addons/com_redhat_subscription_manager/
%endif

# base/cli tools use the gettext domain 'rhsm', while the
# gnome-help tools use domain 'subscription-manager'
%files -f rhsm.lang
%defattr(-,root,root,-)
%if 0%{?suse_version}
%dir %{_sysconfdir}/pki

%if %{use_yum}
    %dir %{_sysconfdir}/yum
    %dir %{_sysconfdir}/yum/pluginconf.d
    %dir %{_prefix}/lib/yum-plugins/
%endif

%if %{use_yum} || %{use_dnf}
    %dir %{_sysconfdir}/yum.repos.d
%endif

%dir %{python_sitearch}/rhsmlib/candlepin
%dir %{python_sitearch}/rhsmlib/compat
%dir %{python_sitearch}/rhsmlib/dbus
%dir %{python_sitearch}/rhsmlib/dbus/facts
%dir %{python_sitearch}/rhsmlib/dbus/objects
%dir %{python_sitearch}/rhsmlib/facts
%dir %{python_sitearch}/rhsmlib/services
%dir %{python_sitearch}/subscription_manager-%{version}-*.egg-info
%dir %{python_sitearch}/subscription_manager/api
%dir %{python_sitearch}/subscription_manager/branding
%dir %{python_sitearch}/subscription_manager/model
%dir %{python_sitearch}/subscription_manager/plugin
%dir %{python_sitearch}/subscription_manager/scripts
%dir %{_var}/spool/rhsm
%dir %{_prefix}/share/polkit-1
%dir %{_prefix}/share/polkit-1/actions
%endif
%if 0%{?suse_version} && 0%{?suse_version} < 1315
%dir %{_prefix}/share/locale/ta_IN
%dir %{_prefix}/share/locale/ta_IN/LC_MESSAGES
%endif
%attr(755,root,root) %{_sbindir}/subscription-manager

# symlink to console-helper
%if !0%{?suse_version}
%{_bindir}/subscription-manager
%endif
%attr(755,root,root) %{_bindir}/rhsmcertd

%attr(755,root,root) %{_libexecdir}/rhsmcertd-worker
%attr(755,root,root) %{_libexecdir}/rhsmd

# our config dirs and files
%attr(755,root,root) %dir %{_sysconfdir}/pki/consumer
%attr(755,root,root) %dir %{_sysconfdir}/pki/entitlement
%attr(755,root,root) %dir %{_sysconfdir}/rhsm
%attr(755,root,root) %dir %{_sysconfdir}/rhsm/facts
%if 0%{?suse_version}
%attr(755,root,root) %dir %{_sysconfdir}/rhsm/zypper.repos.d
%endif

%attr(644,root,root) %config(noreplace) %{_sysconfdir}/rhsm/rhsm.conf
%config %attr(644,root,root) %{_sysconfdir}/rhsm/logging.conf

# PAM config
%if !0%{?suse_version}
%{_sysconfdir}/pam.d/subscription-manager
%{_sysconfdir}/security/console.apps/subscription-manager
%endif

%if %{use_yum} || %{use_dnf}
    %ghost %{_sysconfdir}/yum.repos.d/redhat.repo
%endif

# yum plugin config
%if %{use_yum}
    # remove the repo file when we are deleted
    %config(noreplace) %attr(644,root,root) %{_sysconfdir}/yum/pluginconf.d/subscription-manager.conf
    %config(noreplace) %attr(644,root,root) %{_sysconfdir}/yum/pluginconf.d/product-id.conf
    %config(noreplace) %attr(644,root,root) %{_sysconfdir}/yum/pluginconf.d/search-disabled-repos.conf
%endif

# misc system config
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/logrotate.d/subscription-manager
%attr(700,root,root) %{_sysconfdir}/cron.daily/rhsmd

%attr(755,root,root) %dir %{_var}/log/rhsm
%attr(755,root,root) %dir %{_var}/spool/rhsm/debug
%attr(755,root,root) %dir %{_var}/run/rhsm
%attr(750,root,root) %dir %{_var}/lib/rhsm
%attr(750,root,root) %dir %{_var}/lib/rhsm/facts
%attr(750,root,root) %dir %{_var}/lib/rhsm/packages
%attr(750,root,root) %dir %{_var}/lib/rhsm/cache
%attr(750,root,root) %dir %{_var}/lib/rhsm/repo_server_val

%{_sysconfdir}/bash_completion.d/subscription-manager
%{_sysconfdir}/bash_completion.d/rct
%{_sysconfdir}/bash_completion.d/rhsm-debug
%{_sysconfdir}/bash_completion.d/rhn-migrate-classic-to-rhsm
%{_sysconfdir}/bash_completion.d/rhsmcertd

%if %use_subman_gui
%{_sysconfdir}/bash_completion.d/rhsm-icon
%endif

%dir %{python_sitearch}/subscription_manager

# code, python modules and packages
%{python_sitearch}/subscription_manager-*.egg-info/*
%{python_sitearch}/subscription_manager/*.py*
%{python_sitearch}/subscription_manager/api/*.py*
%{python_sitearch}/subscription_manager/branding/*.py*
%{python_sitearch}/subscription_manager/model/*.py*
%{python_sitearch}/subscription_manager/plugin/__init__.py*
%{python_sitearch}/subscription_manager/scripts/*.py*
%if %{with python3}
%{python_sitearch}/subscription_manager/__pycache__
%{python_sitearch}/subscription_manager/api/__pycache__
%{python_sitearch}/subscription_manager/branding/__pycache__
%{python_sitearch}/subscription_manager/model/__pycache__
%{python_sitearch}/subscription_manager/plugin/__pycache__
%{python_sitearch}/subscription_manager/scripts/__pycache__
%endif

# our gtk2/gtk3 compat modules
%dir %{python_sitearch}/subscription_manager/ga_impls
%{python_sitearch}/subscription_manager/ga_impls/__init__.py*
%if %{with python3}
%{python_sitearch}/subscription_manager/ga_impls/__pycache__
%endif

%if 0%{?gtk3}
%{python_sitearch}/subscription_manager/ga_impls/ga_gtk3.py*
%else
%dir %{python_sitearch}/subscription_manager/ga_impls/ga_gtk2
%{python_sitearch}/subscription_manager/ga_impls/ga_gtk2/*.py*
%endif

# subscription-manager plugins
%dir %{rhsm_plugins_dir}
%dir %{_sysconfdir}/rhsm/pluginconf.d

# yum plugins
# Using _prefix + lib here instead of libdir as that evaluates to /usr/lib64 on x86_64,
# but yum plugins seem to normally be sent to /usr/lib/:
%if %{use_yum}
    %{_prefix}/lib/yum-plugins/subscription-manager.py*
    %{_prefix}/lib/yum-plugins/product-id.py*
    %{_prefix}/lib/yum-plugins/search-disabled-repos.py*
%endif

# zypper plugins
%if 0%{?suse_version}
%{_prefix}/lib/zypp/plugins/services/subscription-manager
%{_prefix}/lib/zypp/plugins/commit/product-id
%endif

# rhsmlib
%dir %{python_sitearch}/rhsmlib
%{python_sitearch}/rhsmlib/*.py*
%{python_sitearch}/rhsmlib/candlepin/*.py*
%{python_sitearch}/rhsmlib/compat/*.py*
%{python_sitearch}/rhsmlib/facts/*.py*
%{python_sitearch}/rhsmlib/services/*.py*
%{python_sitearch}/rhsmlib/dbus/*.py*
%{python_sitearch}/rhsmlib/dbus/facts/*.py*
%{python_sitearch}/rhsmlib/dbus/objects/*.py*
%if %{with python3}
%{python_sitearch}/rhsmlib/__pycache__
%{python_sitearch}/rhsmlib/candlepin/__pycache__
%{python_sitearch}/rhsmlib/compat/__pycache__
%{python_sitearch}/rhsmlib/dbus/__pycache__
%{python_sitearch}/rhsmlib/dbus/facts/__pycache__
%{python_sitearch}/rhsmlib/dbus/objects/__pycache__
%{python_sitearch}/rhsmlib/facts/__pycache__
%{python_sitearch}/rhsmlib/services/__pycache__
%endif

%{_datadir}/polkit-1/actions/com.redhat.*.policy
%{_datadir}/dbus-1/system-services/com.redhat.*.service
%attr(755,root,root) %{_libexecdir}/rhsm*-service

# Despite the name similarity dbus-1/system.d has nothing to do with systemd
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/com.redhat.*.conf
%if %use_systemd
    %attr(644,root,root) %{_unitdir}/*.service
    %attr(644,root,root) %{_tmpfilesdir}/%{name}.conf
%else
    %attr(755,root,root) %{_initrddir}/rhsmcertd
%endif

# Incude rt CLI tool
%dir %{python_sitearch}/rct
%{python_sitearch}/rct/*.py*
%if %{with python3}
%{python_sitearch}/rct/__pycache__
%endif
%attr(755,root,root) %{_bindir}/rct

# Include consumer debug CLI tool
%dir %{python_sitearch}/rhsm_debug
%{python_sitearch}/rhsm_debug/*.py*
%if %{with python3}
%{python_sitearch}/rhsm_debug/__pycache__
%endif
%attr(755,root,root) %{_bindir}/rhsm-debug

%doc
%{_mandir}/man8/subscription-manager.8*
%{_mandir}/man8/rhsmcertd.8*
%{_mandir}/man8/rct.8*
%{_mandir}/man8/rhsm-debug.8*
%{_mandir}/man5/rhsm.conf.5*
%doc LICENSE


%if %{use_rhsm_gtk}
%files -n rhsm-gtk
%defattr(-,root,root,-)
%dir %{python_sitearch}/subscription_manager/gui
%{python_sitearch}/subscription_manager/gui/*.py*
%{python_sitearch}/subscription_manager/gui/data/ui/*.ui
%{python_sitearch}/subscription_manager/gui/data/glade/*.glade
%{python_sitearch}/subscription_manager/gui/data/icons/*.svg
%{_datadir}/icons/hicolor/16x16/apps/*.png
%{_datadir}/icons/hicolor/22x22/apps/*.png
%{_datadir}/icons/hicolor/24x24/apps/*.png
%{_datadir}/icons/hicolor/32x32/apps/*.png
%{_datadir}/icons/hicolor/48x48/apps/*.png
%{_datadir}/icons/hicolor/96x96/apps/*.png
%{_datadir}/icons/hicolor/256x256/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%if %{with python3}
%{python_sitearch}/subscription_manager/gui/__pycache__
%endif
%endif


%if %{use_subman_gui}
#%files -n subscription-manager-gui -f subscription-manager.lang
%files -n subscription-manager-gui
%defattr(-,root,root,-)
%attr(755,root,root) %{_sbindir}/subscription-manager-gui
%if 0%{?suse_version}
%dir %{python_sitearch}/subscription_manager/gui/data
%dir %{python_sitearch}/subscription_manager/gui/data/glade
%dir %{python_sitearch}/subscription_manager/gui/data/icons
%dir %{python_sitearch}/subscription_manager/gui/data/ui
%dir %{_datadir}/appdata
%dir %{_datadir}/gnome
%dir %{_datadir}/gnome/help
%dir %{_datadir}/gnome/help/subscription-manager
%dir %{_datadir}/gnome/help/subscription-manager/C
%dir %{_datadir}/gnome/help/subscription-manager/C/figures
%dir %{_datadir}/omf
%dir %{_datadir}/omf/subscription-manager
%else
# symlink to console-helper
%{_bindir}/subscription-manager-gui
%endif
%{_bindir}/rhsm-icon

%{_datadir}/gnome/help/subscription-manager/C/figures/*.png
%{_datadir}/gnome/help/subscription-manager/C/*.xml
%{_datadir}/omf/subscription-manager/subscription-manager-C.omf

%{_datadir}/applications/subscription-manager-gui.desktop
%{_datadir}/appdata/subscription-manager-gui.appdata.xml

# desktop config files
%{_sysconfdir}/xdg/autostart/rhsm-icon.desktop
%if !0%{?suse_version}
%{_sysconfdir}/pam.d/subscription-manager-gui
%{_sysconfdir}/security/console.apps/subscription-manager-gui
%endif

%{_sysconfdir}/bash_completion.d/subscription-manager-gui

%doc
%{_mandir}/man8/subscription-manager-gui.8*
%{_mandir}/man8/rhsm-icon.8*
%doc LICENSE
%endif


%if %{with initial-setup-addon}
%if %use_initial_setup

%files -n subscription-manager-initial-setup-addon
%defattr(-,root,root,-)
%dir %{_datadir}/anaconda/addons/com_redhat_subscription_manager/
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/*.py*
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/gui/*.py*
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/gui/spokes/*.ui
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/gui/spokes/*.py*
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/categories/*.py*
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/ks/*.py*
%if %{with python3}
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/__pycache__
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/gui/__pycache__
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/gui/spokes/__pycache__
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/categories/__pycache__
%{_datadir}/anaconda/addons/com_redhat_subscription_manager/ks/__pycache__
%endif

%endif
%else
%exclude /usr/share/anaconda/addons/*
%endif

%files -n subscription-manager-migration
%defattr(-,root,root,-)
%dir %{python_sitearch}/subscription_manager/migrate
%{python_sitearch}/subscription_manager/migrate/*.py*
%if %{with python3}
%{python_sitearch}/subscription_manager/migrate/__pycache__
%endif
%attr(755,root,root) %{_sbindir}/rhn-migrate-classic-to-rhsm

%doc
%{_mandir}/man8/rhn-migrate-classic-to-rhsm.8*
%doc LICENSE
%if 0%{?fedora}
%doc README.Fedora
%endif

%if %{with python3}
%files -n %{py_package_prefix}-syspurpose
%defattr(-,root,root,-)
%dir %{python3_sitelib}/syspurpose*.egg-info
%{python3_sitelib}/syspurpose*.egg-info/*
%dir %{_sysconfdir}/rhsm/syspurpose
%dir %{python3_sitelib}/syspurpose
%{python3_sitelib}/syspurpose/{*.py*,__pycache__/*}

%attr(755, root, root) %{_sbindir}/syspurpose
%attr(644,root,root) %{_sysconfdir}/rhsm/syspurpose/valid_fields.json
%endif

%files -n subscription-manager-plugin-container
%defattr(-,root,root,-)
%if 0%{?suse_version}
%dir %{_sysconfdir}/docker
%dir %{_sysconfdir}/docker/certs.d
%dir %{_sysconfdir}/rhsm/ca
%dir %{python_sitearch}/subscription_manager/plugin
%endif
%{_sysconfdir}/rhsm/pluginconf.d/container_content.ContainerContentPlugin.conf
%{rhsm_plugins_dir}/container_content.py*
%if %{with python3}
%{rhsm_plugins_dir}/__pycache__
%endif
%{python_sitearch}/subscription_manager/plugin/container.py*

# Copying Red Hat CA cert into each directory:
%attr(755,root,root) %dir %{_sysconfdir}/docker/certs.d/cdn.redhat.com
%attr(644,root,root) %{_sysconfdir}/rhsm/ca/redhat-entitlement-authority.pem
%attr(644,root,root) %{_sysconfdir}/docker/certs.d/cdn.redhat.com/redhat-entitlement-authority.crt


%if %has_ostree
%files -n subscription-manager-plugin-ostree
%defattr(-,root,root,-)
%{_sysconfdir}/rhsm/pluginconf.d/ostree_content.OstreeContentPlugin.conf
%{rhsm_plugins_dir}/ostree_content.py*
%{python_sitearch}/subscription_manager/plugin/ostree/*.py*
%if %{with python3}
%{python_sitearch}/subscription_manager/plugin/ostree/__pycache__
%endif
%endif


%if %use_firstboot
%files -n subscription-manager-firstboot
%defattr(-,root,root,-)
%if 0%{?suse_version}
%dir %{_datadir}/rhn
%dir %{_datadir}/rhn/up2date_client
%dir %{_datadir}/rhn/up2date_client/firstboot
%endif
# Not explicitly byte compiling this as we do not support firstboot
# on newer versions of fedora
%{_datadir}/rhn/up2date_client/firstboot/rhsm_login.py*
%endif


%if %use_dnf
%files -n dnf-plugin-subscription-manager
%defattr(-,root,root,-)
%{python_sitearch}/dnf-plugins/*
%endif


%files -n %{rhsm_package_name}
%defattr(-,root,root,-)
%dir %{python_sitearch}/rhsm
%{python_sitearch}/rhsm/*

%if %{with python2_rhsm}
%files -n python2-subscription-manager-rhsm
%defattr(-,root,root,-)
%dir %{python2_sitearch}/rhsm
%{python2_sitearch}/rhsm/*
%endif

%files -n subscription-manager-rhsm-certificates
%attr(755,root,root) %dir %{_sysconfdir}/rhsm
%attr(755,root,root) %dir %{_sysconfdir}/rhsm/ca

%attr(644,root,root) %{_sysconfdir}/rhsm/ca/redhat-uep.pem

%if %use_cockpit
%files -n subscription-manager-cockpit
%defattr(-,root,root,-)
%dir %{_datadir}/cockpit/subscription-manager
%{_datadir}/cockpit/subscription-manager/index.html
%{_datadir}/cockpit/subscription-manager/index.min.js.gz
%{_datadir}/cockpit/subscription-manager/subscriptions.css
%{_datadir}/cockpit/subscription-manager/manifest.json
%{_datadir}/cockpit/subscription-manager/po.*.js
%{_datadir}/cockpit/subscription-manager/po.js
%{_datadir}/cockpit/subscription-manager/node_modules/*
%{_datadir}/metainfo/org.cockpit-project.subscription-manager.metainfo.xml
%if ! %use_subman_gui
%{_datadir}/applications/subscription-manager-cockpit.desktop
%{_datadir}/icons/hicolor/16x16/apps/*.png
%{_datadir}/icons/hicolor/22x22/apps/*.png
%{_datadir}/icons/hicolor/24x24/apps/*.png
%{_datadir}/icons/hicolor/32x32/apps/*.png
%{_datadir}/icons/hicolor/48x48/apps/*.png
%{_datadir}/icons/hicolor/96x96/apps/*.png
%{_datadir}/icons/hicolor/256x256/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%endif
%endif

%post
%if %use_systemd
    %if 0%{?suse_version}
        %service_add_post rhsmcertd.service
    %else
        %systemd_post rhsmcertd.service
    %endif
%else
    %if 0%{?suse_version}
        %fillup_and_insserv -f rhsmcertd
    %else
        chkconfig --add rhsmcertd
    %endif
%endif

if [ -x /bin/dbus-send ] ; then
    dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig > /dev/null 2>&1 || :
fi

%if !%use_systemd
if [ "$1" -eq "2" ] ; then
    /sbin/service rhsmcertd condrestart >/dev/null 2>&1 || :
fi
%endif

%if %{use_subman_gui}
%post -n subscription-manager-gui
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
%if !0%{?suse_version}
scrollkeeper-update -q -o %{_datadir}/omf/%{name} || :
%endif
%endif

%post -n subscription-manager-plugin-container
%{__python} %{rhsm_plugins_dir}/container_content.py || :

%preun
if [ $1 -eq 0 ] ; then
    %if %use_systemd
        %systemd_preun rhsmcertd.service
    %else
        /sbin/service rhsmcertd stop >/dev/null 2>&1
        /sbin/chkconfig --del rhsmcertd
    %endif

    if [ -x /bin/dbus-send ] ; then
        dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig > /dev/null 2>&1 || :
    fi
fi

%postun
%if %use_systemd
    %if 0%{?suse_version}
        %service_del_postun rhsmcertd.service
    %else
        %systemd_postun_with_restart rhsmcertd.service
    %endif
%endif

%if %{use_subman_gui}
%postun -n subscription-manager-gui
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    %if !0%{?suse_version}
    scrollkeeper-update -q || :
    %endif
fi
%posttrans -n subscription-manager-gui
touch --no-create %{_datadir}/icons/hicolor &>/dev/null
gtk-update-icon-cache -f %{_datadir}/icons/hicolor &>/dev/null || :
%endif

%changelog
* Mon Mar 23 2020 openEuler Buildteam <buildteam@openeuler.org> - 1.23.3-5
- add necessary marcos for self-building

* Thu Mar 12 2020 openEuler Buildteam <buildteam@openeuler.org> - 1.23.3-4
- Remove some default installation packages

* Fri Dec 27 2019 openEuler Buildteam <buildteam@openeuler.org> - 1.23.3-3
- fix module 'os' has no attribute 'errno' error

* Mon Sep 23 2019 zoujing<zoujing13@huawei.com> - 1.23.3-2
- Package init
